linguini-cli 0.1.0-alpha.2

Command-line interface for Linguini localization projects
docs.rs failed to build linguini-cli-0.1.0-alpha.2
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.